@@ -6,6 +6,9 @@ use warnings;
 use Moo;
 use strictures 2;
 use namespace::clean;
+
+extends 'OpenAI::API::Request';
+
 use Types::Standard qw(Bool Str Num Int Map);
 
 has input => ( is => 'rw', isa => Str, required => 1, );
@@ -13,6 +16,7 @@ has input => ( is => 'rw', isa => Str, required => 1, );
 has model => ( is => 'rw', isa => Str, );
 
 sub endpoint { 'moderations' }
+sub method   { 'POST' }
 
 1;
 
@@ -22,6 +26,16 @@ __END__
 
 OpenAI::API::Request::Moderation - moderations endpoint
 
+=head1 SYNOPSIS
+
+    use OpenAI::API::Request::Moderation;
+
+    my $request = OpenAI::API::Request::Moderation->new(
+        input => "I like turtles",
+    );
+
+    my $res = $request->send();
+
 =head1 DESCRIPTION
 
 Given a input text, outputs if the model classifies it as violating
